@@ -7,8 +7,12 @@ import markdown2 as md
 
 def markdown(content):
     return md.markdown(
-            content,
-            extras=['header-ids'], )
+        content,
+        extras=[
+            'footnotes',
+            'markdown-in-html',
+            'smarty-pants',
+            'header-ids'], )
 
 
 def pygmentize(content):
